Stan Math Library: stan/math/prim/scal/fun/inv_cloglog.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

inv_cloglog.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_FUN_INV_CLOGLOG_HPP
2 #define STAN_MATH_PRIM_SCAL_FUN_INV_CLOGLOG_HPP
3
4 #include <boost/math/tools/promotion.hpp>
5
6 namespace stan {
7 namespace math {
8
47 template <typename T>
48 inline typename boost::math::tools::promote_args<T>::type
49 inv_cloglog(T x) {
50 using std::exp;
51 return 1 - exp(-exp(x));
52 }
53
54 }
55 }
56
57 #endif
stan
Definition: log_sum_exp.hpp:8
stan::math::exp
fvar< T > exp(const fvar< T > &x)
Definition: exp.hpp:10
stan::math::inv_cloglog
fvar< T > inv_cloglog(const fvar< T > &x)
Definition: inv_cloglog.hpp:15

[ Stan Home Page ] © 2011–2016, Stan Development Team.